function SISOoptions = SIM_CreateSISOoptions(Slowest_Oscillation,F1,F2,Ts,BW,TC,OV,ZETAD,STC,FITP)
%
%   Syntax:
%   SISOoptions = SIM_CreateSISOoptions(Slowest_Oscillation,F1,F2,Ts,BW,TC,OV,ZETAD,STC,FITP)
%
%   Create Options Object for SISO system
%
%   Authors: Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%
Fs = 1/Ts;
sample_time = Ts;

T_win = 2*Slowest_Oscillation;
Window_Length = floor(T_win/sample_time);

SISOoptions.FDmethod = 'etfe';
SISOoptions.N = 128;
SISOoptions.auto = 1;
SISOoptions.Fs = 1/Ts;
SISOoptions.f1 = F1;  % in RAD/S % for pitch chirp - z I found good f1 = rad_s2Hz(0.01),
SISOoptions.f2 = F2; %rad_s2Hz(12.28); % 12 - 15 ? in RAD/S % for pitch chirp - z I found good f2 = rad_s2Hz(8.28)
SISOoptions.a = exp(1i*2*pi*SISOoptions.f1/Fs);
SISOoptions.Ts = Ts; 
SISOoptions.Window = hanning(Window_Length); %1024
SISOoptions.Noverlap = floor(Window_Length/2); % 512
SISOoptions.NFFT = 1024*8; % 1024
SISOoptions.plot = 1;
SISOoptions.C_e = sqrt(0.55); 
SISOoptions.WindowLen = Window_Length;
SISOoptions.Resol = SISOoptions.NFFT;
clear T_win; clear Window_Length; clear Slowest_Oscillation; clear Ts_flag; 
SISOoptions.m = 1024;

% PERFORMANCE SPECIFICATIONS:
SISOoptions.Bandwidth = BW;
SISOoptions.TimeConstant = TC;
SISOoptions.Overshoot = OV;
SISOoptions.Zeta = ZETAD;
SISOoptions.SettlingTimeCr = STC
SISOoptions.Fit = FITP
end