%%  AIROBOTS Coaxial Helicopter Prototype Simulator Identified Models
%
%   Authors: Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%
%   The Attitude and Translational models used in the AIROBOTS Coaxial
%   Helicopter Prototype Linear Simulator are based on Frequency-Domain
%   System Identification. 
%
%   -----------------------------------------------------------------------
%   1.   Roll - Pitch Identified subsystem:
%   -----------------------------------------------------------------------
%   
%   This model is based on the hybrid rotors/fuselage model. It accounts
%   not only for the rigid body dynamics but also with the coupling between
%   the lower, upper coaxial rotors blade flapping and the flybar flapping
%   with the rigid body.
%
%   The model assumes that blade coning and lagging as negligible. 
%
%   States:
%   \phi, p, \theta, q, \alpha, \beta, \gamma, \delta, \epsilon, \zeta
%
%   Inputs:
%   \phi_{1c}, \phi_{1s}
%
%   \alpha, \beta   : longitudinal and lateral lower rotor blade flapping
%   \gamma, \delta  : longitudinal and lateral upper rotor blade flapping
%   \epsilon, \zeta : longitudinal and lateral flybar rotor blade flapping
%
%   \phi_{1c}, \phi_{1s} : longitudinal and lateral swashplate tilting
%
%   Both \phi_{1c}, \phi_{1s} excite all states. Towards the need of
%   simplification two normalized control actions u_{roll}, u_{pitch} are
%   formulated based on the kinematics mixing and estimations about the
%   rotor phase offset. 
%
%   -----------------------------------------------------------------------
%   2.   Yaw-Heave Identified subsystem:
%   -----------------------------------------------------------------------
%
%   This model is based on first-order modeling of the yaw rate and the
%   heave velocity. Both yaw and heave are excited from the swashplate
%   height (controlling lower rotor collective) and \Omega (not
%   equivalently). 
%
%   States:
%   \psi, \r, z, w
%
%   Inputs:
%   h_{sp}, \Omega
%
%   Towards the need for simplificantion, two normalized control actions
%   u_{yaw}, u_{thrust} are formulated based on the kinematics of the
%   swashplate and an identified model between a normalized input and
%   \Omega. 
% 
%   -----------------------------------------------------------------------
%   3.   Linear Velocities Dynamics
%   -----------------------------------------------------------------------
%
%   The linear velocities models are based on the assumption that the
%   translational and attitude subsystems can be modeled as two cascaded
%   subsystems. To derive the linear velocity models, the attitude
%   closed-loop model was identified as an intermediate step. Fixing this
%   model cascaded with a first order model structure, the velocity
%   dynamics were captured. 
%
%   States:
%   x, u, y , v
%   
%   Inputs:
%   \theta, \phi
%