%%  ACX IDENTIFIED MODEL SIMULATOR
%
%   This Simulator is based on the Identified High-Order Dynamics of the
%   AIRobots COAXial Prototype (from now on refered as ACX).
%
%   Author: Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%           Authonomous Systems Lab - ETHZ
%
%

%%  ADD PATH
clc;
disp('### Configuring MATLAB Path');
addpath(genpath('../ACX_Simulator/ACX_SIM_CTRL'));
addpath(genpath('../ACX_Simulator/ACX_SRC'));
addpath(genpath('../ACX_Simulator/Analysis_Functions'));
addpath(genpath('../ACX_Simulator/Datasets'));
addpath(genpath('../ACX_Simulator/Figures'));
addpath(genpath('../ACX_Simulator/FILTERS'));
addpath(genpath('../ACX_Simulator/Help_Files'));
addpath(genpath('../ACX_Simulator/IDed_Models'));
addpath(genpath('../ACX_Simulator/Images'));
addpath(genpath('../ACX_Simulator/Initialization'));
addpath(genpath('../ACX_Simulator/Nonparametric_ID'));
addpath(genpath('../ACX_Simulator/Parametric_ID'));
addpath(genpath('../ACX_Simulator/Plotting_Functions'));
addpath(genpath('../ACX_Simulator/Other_Functions'));

%%  LOAD SIMULATION VARIABLES:
clc;
disp('### ACX Simulator Initializing...');
Ts = 0.011; sample_time = Ts;
atti_init_vector = zeros(10,1);
yaw_heave_init_vector = zeros(4,1);
pos_vel_init_vector = zeros(4,1);

%%  LOAD Kinematics Variables:

load('../ACX_Simulator/ACX_SRC/ACX_CFGs.mat');
disp('### ACX Kinematics variables loaded...');
%%  LOAD Identified Models:
old_matlab_flag = input('$$$ Do you have MATLAB version older than 2010[0/1]?');
if(old_matlab_flag~=1)
load('../ACX_Simulator/IDed_Models/Attitude/ATTI_SS.mat');
load('../ACX_Simulator/IDed_Models/Attitude/ATTI_SS_FO.mat');
load('../ACX_Simulator/IDed_Models/Yaw_Heave/RW_HO_SS.mat');
load('../ACX_Simulator/IDed_Models/Velocity/VEL_CASC_ATTI.mat');
load('../ACX_Simulator/IDed_Models/Velocity/VEL_CASC_ATTI_SS.mat');
load('../ACX_Simulator/IDed_Models/Attitude/ATTI_AUG_SMALL_INPUTS.mat');
load('../ACX_Simulator/IDed_Models/Yaw_Heave/Uthrust_RPM.mat');
Ut_rpm = tf(Uthrust_RPM); Ut_rpm = Ut_rpm(1);
load('../ACX_Simulator/IDed_Models/Yaw_Heave/R_MISO.mat');
load('../ACX_Simulator/IDed_Models/Yaw_Heave/W_MISO.mat');
disp('### ACX Identified Models loaded...');
else

load('../ACX_Simulator/IDed_Models/Attitude/ATTI_SS_ELEMENTS.mat');
load('../ACX_Simulator/IDed_Models/Attitude/ATTI_SS_FO_ELEMENTS.mat');
load('../ACX_Simulator/IDed_Models/Yaw_Heave/RW_HO_SS_ELEMENT.mat');
load('../ACX_Simulator/IDed_Models/Velocity/VEL_CASC_ATTI_ELEMENTS.mat');
load('../ACX_Simulator/IDed_Models/Velocity/VEL_CASC_ATTI_SS_ELEMENTS.mat');
load('../ACX_Simulator/IDed_Models/Attitude/ATTI_AUG_SMALL_INPUTS_ELEMENTS.mat');
load('../ACX_Simulator/IDed_Models/Yaw_Heave/Uthrust_RPM_ELEMENTS.mat');
load('../ACX_Simulator/IDed_Models/Yaw_Heave/R_MISO_ELEMENTS.mat');
load('../ACX_Simulator/IDed_Models/Yaw_Heave/W_MISO_ELEMENTS.mat');

run CreateSS_oldMATLAB
end
%%  LOAD Filters:
load('../ACX_Simulator/FILTERS/ACCEL_FILT.mat');
if(old_matlab_flag~=1)
    load('../ACX_Simulator/FILTERS/WASHOUT_A.mat');
else
    load('../ACX_Simulator/FILTERS/WASHOUT_A_ELEMENTS.mat');
    WO_TF =  tf(WO_TF_num,WO_TF_den);
end
WO_TF_d = c2d(WO_TF,Ts,'zoh');
disp('### ACX State filters loaded...');

%%  LOAD ATTITUDE GAIN SCHEDULING

delta_roll = deg2rad(20);
NumOfSteps = 50;
K_P_GS_ATTI = (0.5/50)*(1:NumOfSteps);

delta_yaw = deg2rad(45);
K_GS_Rrate = (0.15/50)*(1:NumOfSteps);
delta_r_rate = deg2rad(45);
K_GS_Yaw = (0.085/50)*(1:NumOfSteps);
disp('### ACX Attitude Gain Scheduling Parameters loaded...');

%%  LOAD HEAVE GAIN SCHEDULING

NumOfSteps = 50;
delta_heave = 0.2;
K_GS_Heave = (0.08/50)*(1:NumOfSteps);
disp('### ACX Heave Gain Scheduling Parameters loaded...');

%%  LOAD VELOCITY - POSITION GAIN SCHEDULE

K_G = [0.03 0.03 0.04 0.1 0.16 0.13 0.12];
K_G = [0.115 0.12 0.13 0.12 0.11 0.1 0.1] ;
error_s = [0 0.1 0.2 0.25 0.3 0.4 0.5];
load('../ACX_Simulator/ACX_SIM_CTRL/Position_Velocity/GAINSCH_KP_B.mat');
error_s = 0:0.01:0.5;
K_G_S = GAINSCH(error_s);

switch_K_G = floor(error_s*(length(error_s)-1)/0.5)+1;

GainSchedule_ACC = [0.0025 0.005 0.0125 0.0175 0.025];
GainSchedule_ACC = (0.025/50)*[1:50];
GainSchedule_POS = (0.175/10)*[1:10];
disp('### ACX Velocity Gain Scheduling Parameters loaded...');

%%  TRAJECTORY DATA
m = 1.16;
g = 9.81;
Tnom = m*g;
% X_WPTS = 2*sin(0:0.01:10);
% Y_WPTS = 2*cos(0:0.01:10);
X_WPTS = [-1.6 -1.6 0.05 0.05 -1.6]; X_WPTS_S = X_WPTS;
Y_WPTS = [0.4 -1.2 -1.2 0.4 0.4];    Y_WPTS_S = Y_WPTS;
X_WPTS = [0.05 0.05 -0.8]; X_WPTS_S = X_WPTS;
Y_WPTS = [-1.2 0.4 0.4]; Y_WPTS_S = Y_WPTS;
X_WPTS = [-0.8 0.05 0.05 0.05 -0.8];
Y_WPTS = [0.4 0.4 -1.0 0.4 0.4];
X_WPTS = [-0.8 -0.425 -0.425 0.05 0.05]; %0.05 0.05 -0.8];
Y_WPTS = [0.4 0.4 -1 -1 0.4;];
X_WPTS_S = X_WPTS;
Y_WPTS_S = Y_WPTS;
Coarsity = 32;
plot_flag = [];
X_WPTS_COARSE = X_WPTS;
Y_WPTS_COARSE = Y_WPTS;
[X_WPTS_S,Y_WPTS_S,SOUT,EXITFLAGS] = ACX_Smooth_Trajectory(X_WPTS,Y_WPTS,Coarsity,plot_flag);
X_WPTS_S(end-3) = X_WPTS_S(end-4)+0.0001;
X_WPTS_S(end-2) = X_WPTS_S(end-3)+0.0002;
X_WPTS_S(end-1) = X_WPTS_S(end-2)+0.0003;
Y_WPTS_S(end-3) = Y_WPTS_S(end-4)+0.0001;
Y_WPTS_S(end-2) = Y_WPTS_S(end-3)+0.0002;
Y_WPTS_S(end-1) = Y_WPTS_S(end-2)+0.0003;
X_WPTS_S(2) = X_WPTS_S(1) + 0.00001;
X_WPTS_S(3) = X_WPTS_S(1) + 0.00002;
X_WPTS_S(6) = X_WPTS_S(5) + 0.0001;
X_WPTS_S(7) = X_WPTS_S(5) + 0.0002;
Y_WPTS_S(2) = Y_WPTS_S(1) + 0.00001;
Y_WPTS_S(3) = Y_WPTS_S(1) + 0.00002;
Y_WPTS_S(6) = Y_WPTS_S(5) + 0.0001;
Y_WPTS_S(7) = Y_WPTS_S(5) + 0.0002;
X_WPTS = X_WPTS_S;
Y_WPTS = Y_WPTS_S;

pos_vel_init_vector(1) = X_WPTS(1); pos_vel_init_vector(3) = Y_WPTS(1);
disp('### ACX Reference Trajectory loaded...');

%%  COMPUTE MODEL - BASED CONTROLLERS

% run ACX_SIM_ATTI_LQG;
% run ACX_SIM_YAW_LQ;
% run ACX_SIM_YAW_SISO_LQ;
run ACX_SIM_HEAVE_SISO_PID;
load('../ACX_Simulator/ACX_SIM_CTRL/Attitude/LowOrderLS.mat');
disp('### Model Based Controllers computed');
clc;

load('../ACX_Simulator/ACX_SIM_CTRL/Attitude/LQGCONSSatti_ELEMENTS.mat');
run CreateCTRL_oMATLAB
load('../ACX_Simulator/ACX_SIM_CTRL/Attitude/KSEyaw.mat');
load('../ACX_Simulator/ACX_SIM_CTRL/Attitude/KSEyaw_simo.mat');

%%  
disp('## ACX Simulator Initialized!');