%%  ACX Simulator L(inear) - Nonparametric Identification Functions
%
%   Authors: Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)

%%  CREATE OPTIONS OBJECT

Slowest_Oscillation = 5;
F1 = 0.1;
F2 = 2;
BW = 10;
TC = 0.5;
OV = 10;
ZETAD = 0.35;
STC = 1;
FITP = 30;
SISOoptions = SIM_CreateSISOoptions(Slowest_Oscillation,F1,F2,Ts,BW,TC,OV,ZETAD,STC,FITP)

%%  Define input_vec, output_vec based on the experimental recorded datasets

input_vec = ID_Datasets.OpenLoop{1}.Uroll.values;
output_vec = ID_Datasets.OpenLoop{1}.p.values;

%%  Create ID Data Object (TD)
data = iddata(output_vec,input_vec,Ts);

if(exist('time_vec','var')==0)
    time_vec = Ts*(1:length(input_vec)) - Ts;
end

%%  ACX CTRLDI SISO: Quick Filter

filt_vec = [0.1 12];
data_f = idfilt(data,filt_vec);

cio_f = input('Change Input-Output and use the Filtered version? [0/1]  ');
if(cio_f == 1)
    input_vec = data_f.InputData;
    output_vec = data_f.OutputData;
end

%%  ACX CTRLDI SISO: Experimental Step Response Check

SISO_STEP_TEST_EXP = ACX_SIM_SISO_Exp_Step_Test(input_vec,output_vec,time_vec,SISOoptions)

%%  ACX CTRLDI SISO: Experimental Reference - Response Fitting and Coherence Analysis

IOCheck = ACX_SIM_SISO_ResponseCheck(input_vec,output_vec,SISOoptions)

%%  ACX CTRLDI SISO: Experimental Step - Response Damping Analysis

DAMP_Analysis = ACX_SIM_SISO_STEP_DampingAnalysis(input_vec,output_vec,SISOoptions)

%%  ACX CTRLDI SISO: Input/Output Experimental Spectrogram Analysis

[Spectro] = SIM_SpectrogramIO(input_vec,output_vec,SISOoptions);

%%  ACX CTRLDI SISO: Input/Output Power Spectral Density Estimate

[PSDuu,PSDyy,PSDuy] = SIM_PSD_IO(input_vec,output_vec,SISOoptions);

PSD_SNR.Output = PSD_StN_ratio(PSDyy,SISOoptions)
PSD_SNR.Input = PSD_StN_ratio(PSDuu,SISOoptions)


%%  ACX CTRLDI SISO: Input/Output Delay Estimation

EstimatedDelayInSamples = delayest(data) 

%%  ACX CTRLDI SISO: Experimental Responses Frequency Domain Analysis

FRD_Analysis = ACX_SIM_SISO_FRD_Analysis(input_vec,output_vec,Ts,SISOoptions)

%%  ACX SISOA: Process Model ID
%   This functionality provides the capability to identify a SISO transfer
%   function. It is based on "Process Models ID" since we expect that SISO
%   models will be of relatively low order. At least this makes sense in
%   terms of physical interpetation. 

%   Type String:
%   P for Process Model (required)
%   0,1,2 or 3 for process poles (required)
%   D to incluse time delay (optional)
%   Z to include a process zero (optional)
%   U to indicate possible complex-valued (underdamped) poles (optional)
%   I to indicate enforced integration (optional)
%
%   You can make some of the parameters 'fixed' if you know them from
%   previous data. Just type "help idproc" to find out how!

cprintf('SystemCommands', '********************************************************************\n');
cprintf('-Blue',          'Note that sometimes TD lead to different ID compared to FD data!\n');
cprintf('-Red',           'This seems to be related with the stability properties of the system\n');
cprintf('SystemCommands', '********************************************************************\n');

%SISOoptions.f2 = rad_s2Hz(6.58)
clear PM_TypeString;
PM_TypeString = 'P1';
SISO_TF = idproc(PM_TypeString);

%   Select Data Type [0-6] (TD,FD,ETFE,SPA,SPAFDR,CZTidfrd)
data_type = 1;
ok_flag = 0;
switch data_type
    case 1
        proc_id_data = data;
        cprintf('-Blue','TIME-DOMAIN Data object\n');
        ok_flag = 1;
    case 2
        proc_id_data = fft(data);
        cprintf('-Blue','FREQ-DOMAIN FFT Data object\n');
        ok_flag = 1;
    case 3 
        proc_id_data = etfe(data);
        cprintf('-Blue','ETFE ESTIMATION object\n');
        ok_flag = 1;
    case 4
        proc_id_data = spa(data);
        cprintf('-Blue','SPA ESTIMATION object\n');
        ok_flag = 1;
    case 5
        proc_id_data = spafdr(data);
        cprintf('-Blue','SPAFDR ESTIMATION object\n');
        ok_flag = 1;
    case 6
        proc_id_data = CZTidfrd(data,SISOoptions);
        cprintf('-Blue','FREQ-DOMAIN CZT Data object\n');
        cprintf('-SystemCommands','Chirp-Z is extremely sensitive in the correct frequency selection!\n');
        ok_flag = 1;
    otherwise
        cprintf('-Red','You must select between 1->6 \n');
end

cprintf('SystemCommands','*************************************************\n');
cprintf('Blue',          'Consider fixing the DC-GAIN of the IDed System!!!\n');
cprintf('SystemCommands','*************************************************\n');

if(ok_flag == 1)
    SISO_TF = ACX_ID_Process_Model_ID(proc_id_data,SISO_TF,SISOoptions);
    cprintf('Blue','SISO TF estimated!\n');
    cprintf('Blue','Note: In case you know some parameters already you can hardcode them and make the estimation status "fixed". Type "help idproc" to find out how.\n');
end

id_metrics_flag = input('Do you want to see ID metrics (based on the same dataset here)[0/1]');
if(id_metrics_flag == 1)
    MdlMetrics = ACX_MATLABSID_METRICS(SISO_TF,data);
    cprintf('-Blue','Note that you should make the validation also with a data set not used in ID\n');
end

cprintf('Blue','Creating the "systf" object for ACX_SISOAN_MDL analysis\n');
systf = tf(SISO_TF);
systf = systf(1,1);

%%  