function SISO_STEP_TEST = ACX_SIM_SISO_Exp_Step_Test(u,y,t,options)
%
%   Syntax:
%   SISO_STEP_TEST = ACX_SIM_SISO_Exp_Step_Test(u,y,t,options)
%   
%   ACX ConTRoL Design Interfrace
%
%   Outputs:
%   SISO_STEP_TEST
%   SISO_STEP_TEST.TimeConstant : Dominant Time Constant
%   SISO_STEP_TEST.SSvalue      : Steady State valude
%   SISO_STEP_TEST.OvershootValue : Overshoot value (%)
%
%   Inputs:
%   u           : Input vector
%   y           : Output vector
%   t           : time vector
%   options     : options structure
%   options.TimeConstant : maximum acceptable time constant
%   options.Overshoot    : maximum acceptable overshoot
%   options.SettlingTimeCr : Settling Time Criterion (%)
%
%   Authors: Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

yy = abs(y);
fv = y(end);

flag_tc = 0;
%if(fv>=0)
for i = 1:length(yy)
    if(yy(i)>= 0.63*abs(fv))
       tc = t(i);
       y_tc = y(i);
       flag_tc = 1;
    end
    if(flag_tc == 1)
       break
    end
end

if(fv>=0)
    oversh_value = abs(max(y) - fv);
else
    oversh_value = abs(min(y) - fv);
end

max_y = max(y);
for i = 1:length(y)
    if(y(i) == max_y)
        t_max = t(i);
    end
end
        

oversh_value = 100*(oversh_value/abs(fv));
if(tc<=options.TimeConstant)
    cprintf('Blue','Time Constant is good!\n');
    flag_tc = 1;
else
    cprintf('Red','Time Constant is higher than desired\n');
    flag_tc = 0;
end

if(oversh_value<=options.Overshoot)
   cprintf('Blue','Overshoot is small enough!\n');
   flag_ov = 1;
else
    cprintf('Red','Overshoot is too big\n');
    flag_ov = 0;
end

fvu = u(end);

dcg_apr = fv/fvu;

min_settling_y = fv - (options.SettlingTimeCr/100)*abs(fv);
max_settling_y = fv + (options.SettlingTimeCr/100)*abs(fv);

    
for i = 1:length(y)
    if((y(i)>=min_settling_y)&&(y(i)<=max_settling_y))
        flag_st = 1;
        for j = (i+1):length(y)
            if((y(j)<min_settling_y)||(y(j)>max_settling_y))
                flag_st = 0;
            end
        end
        if(flag_st==1)
            settling_time = t(i);
            break;
        end
    end
end

% S = stepinfo(y,t,'SettlingTimeThreshold',options.SettlingTimeCr/100);

SISO_STEP_TEST.TimeConstant = tc;
SISO_STEP_TEST.SSvalue = fv;
SISO_STEP_TEST.OvershootValue = oversh_value;
SISO_STEP_TEST.DCgain = dcg_apr;
SISO_STEP_TEST.SettlingTime = settling_time;

t = t - t(1);

if(tc<10^10)
    LineTCx = 0:0.1:tc;
    LineTCy(1:length(LineTCx)) = y_tc;
end

if(oversh_value>0)
    LineOVy = fv:0.01:max_y;
    LineOVx(1:length(LineOVy)) = t_max;
end

figure
subplot(2,1,1)
plot(t,y,'b','LineWidth',2.0);
hold on
if(tc<10^10)
    if(flag_tc == 1)
        plot(LineTCx,LineTCy,'g--','LineWidth',2.0);
        plot(tc,y_tc,'go','LineWidth',3.0);
    else
        plot(LineTCx,LineTCy,'r--','LineWidth',2.0);
        plot(tc,y_tc,'ro','LineWidth',3.0);
    end
end

if(oversh_value>0)
    if(flag_ov==1)
        plot(LineOVx,LineOVy,'g--','LineWidth',2.0);
        plot(t_max,max_y,'go','LineWidth',3.0);
    else
        plot(LineOVx,LineOVy,'r--','LineWidth',2.0);
        plot(t_max,max_y,'ro','LineWidth',3.0);
    end
end
xlabel('Time (s)'); ylabel('Response');
grid on;
title({'Input-Response Plot'; ['Time Constant = ' num2str(tc) ' , Steady State = ' num2str(fv) ' , Overshoot = ' num2str(oversh_value) ' , DCgain = ' num2str(dcg_apr)]});
subplot(2,1,2)
plot(t,u,'b','LineWidth',2.0);
xlabel('Time (s)'); ylabel('Input');
grid on;
end