function siso_mdl = ACX_SIM_2ndOrder_SISO_SS_ID(data,par_init,init_state,options)
%
%   Syntax:
%   siso_mdl = ACX_SIM_2ndOrder_SISO_SS_ID(data,par_init,init_state,options)
%   
%   Inputs:
%   data            : iddata object
%   par_init        : par_init(1), par_init(2), par(3) init parameters of
%   the ode \ddot{x} = par_init(1)*\dot{x}+par_init(2)*x + par_init(3)*u
%   init_state      : initial state 
%   options         : structure that contains the following
%   options.Ts         = sampling time
%           options.Disturbance == 1 means that disturbance model estimated
%           
%   Outputs:
%   siso_mdl        : 2nd order SISO State Space Model
%   
%   Estimates 2nd order Single Input/Single Output State Space Model
%
%   Authors:    Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

siso_mdl_struct = idgrey('ACX_SIM_SISO_2ndOrder_SS',[par_init(1) par_init(2) par_init(3) init_state], 'c', 0*options.Ts);

if(isfield(options,'Disturbance'))
    if(options.Disturbance == 0)
        siso_mdl = pem(data,siso_mdl_struct);
    else
        siso_mdl = pem(data,siso_mdl_struct,'DisturbanceModel','None','InitialState','Zero');
    end
else
    siso_mdl = pem(data,siso_mdl_struct);
end


end