function MdlMetrics = ACX_SIM_MATLABSID_METRICS(id_model,vdata)
%
%   Syntax:
%   MdlMetrics = ACX_SIM_MATLABSID_METRICS(id_model,vdata)
%   
%
%   ### AIROBOTS COAX Small System Identification Toolbox
%
%   This function provides Akaike Metrics, Fitting Percentage, residual
%   analysis, CovarianceMatrix for parameters and State-Space matrices
%   standard deviations. Its aim is to directly support the user to judge
%   if an identification is good enough. Note that this function should be
%   also called with data sets different that those used in the
%   identification process.
%
%   Authors: Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)

contains_multiple = isa(id_model,'cell');

if(contains_multiple == 0)

MdlMetrics.FinalPredictionError = fpe(id_model);
MdlMetrics.FPE = MdlMetrics.FinalPredictionError;
MdlMetrics.AkaikeInformationCriterion = aic(id_model);
MdlMetrics.AIC = MdlMetrics.AkaikeInformationCriterion;

[yh,fit,x0] = compare(vdata,id_model);
MdlMetrics.Fit = fit;

cprintf('SystemCommands','-------------------------------------------------\n');
cprintf('Black',         '     MATLAB-METRICS BASED ACCURACY ANALYSIS      \n');
cprintf('SystemCommands','-------------------------------------------------\n');
cprintf('SystemCommands','\n');
cprintf('Blue',          'Akaike Final Prediction Error = %f \n',MdlMetrics.FPE);
cprintf('SystemCommands','          ----------------------------           \n');
cprintf('Blue'          ,'Akaike Information Criterion = %f \n',MdlMetrics.AIC);
cprintf('Black',         '-------------------------------------------------\n');
cprintf('Blue'          ,'Fitting Percentage = %d \n', fit);
cprintf('SystemCommands','-------------------------------------------------\n');
compare(vdata,id_model)

cprintf('SystemCommands','Press any key to cont.\n');
pause;
if(isempty(id_model.CovarianceMatrix))
     MdlMetrics.CovarianceMatrix = [];
     cprintf('Red','The Covariance Matrix was unreliable and thus not stored!\n');
else
    cprintf('Blue','Covariance Matrix...\n');
    id_model.CovarianceMatrix
    MdlMetrics.CovarianceMatrix = id_model.CovarianceMatrix;
    cprintf('Black',         '-------------------------------------------------\n');
end

if(isa(id_model,'ss'))
if(isempty(id_model.dA))
     MdlMetrics.MatrixStandardDeviations.dA =[];
     MdlMetrics.MatrixStandardDeviations.dB =[];
     MdlMetrics.MatrixStandardDeviations.dC =[];
     MdlMetrics.MatrixStandardDeviations.dD =[];
else
    cprintf('Blue','Standard Deviation of A Matrix...\n');
    id_model.dA
    MdlMetrics.MatrixStandardDeviations.dA = id_model.dA;
    cprintf('Black',         '          -----------------------------          \n');
    cprintf('Blue','Standard Deviation of B Matrix...\n');
    id_model.dB
    MdlMetrics.MatrixStandardDeviations.dB = id_model.dB;
    cprintf('Black',         '          -----------------------------          \n');
    cprintf('Blue','Standard Deviation of C Matrix...\n');
    id_model.dC
    MdlMetrics.MatrixStandardDeviations.dC = id_model.dC;
    cprintf('Black',         '          -----------------------------          \n');
    cprintf('Blue','Standard Deviation of D Matrix...\n');
    id_model.dD
    MdlMetrics.MatrixStandardDeviations.dD = id_model.dD;
end
end

cprintf('SystemCommands','Press any key to see residual analysis... \n');
cprintf('SystemCommands','-------------------------------------------------\n');
cprintf('Blue',          'Residual analysis...\n');
resid(id_model,vdata,'fr');

cprintf('Green','END OF ANALYSIS. Hope you have a nice model! \n');

adv_flag = input('Do you also want to see the results of MATLAB "advice(model)" command [0/1]?');
if(adv_flag==1)
    advice(id_model)
end

close all;

else
% MANY MODELS!
[~,Models_i] = size(id_model);

for i = 1:Models_i
MdlMetrics{i}.FinalPredictionError = fpe(id_model{i});
MdlMetrics{i}.FPE = MdlMetrics{i}.FinalPredictionError;
MdlMetrics{i}.AkaikeInformationCriterion = aic(id_model{i});
MdlMetrics{i}.AIC = MdlMetrics{i}.AkaikeInformationCriterion;

[yh,fit,x0] = compare(vdata,id_model{i});
MdlMetrics{i}.Fit = fit;

cprintf('SystemCommands','-------------------------------------------------\n');
cprintf('Black',        '     MATLAB-METRICS BASED ACCURACY ANALYSIS      \n');
cprintf('SystemCommands','-------------------------------------------------\n');
cprintf('SystemCommands','\n');
cprintf('Blue',          'Akaike Final Prediction Error = %f \n',MdlMetrics{i}.FPE);
cprintf('SystemCommands','          ----------------------------           \n');
cprintf('Blue'          ,'Akaike Information Criterion = %f \n',MdlMetrics{i}.AIC);
cprintf('Black',         '-------------------------------------------------\n');
cprintf('Blue'          ,'Fitting Percentage = %d \n', fit);
cprintf('SystemCommands','-------------------------------------------------\n');
compare(vdata,id_model{i})

if(isempty(id_model{i}.CovarianceMatrix))
    MdlMetrics{i}.CovarianceMatrix = [];
    cprintf('Red','The Covariance Matrix was unreliable and thus not stored!\n');
else
    cprintf('Blue','Covariance Matrix...\n');
    id_model{i}.CovarianceMatrix
    MdlMetrics{i}.CovarianceMatrix = id_model{i}.CovarianceMatrix;
    cprintf('Black',         '-------------------------------------------------\n');
end

if(isa(idmodel{i},'ss'))
if(isempty(id_model{i}.dA))
    MdlMetrics{i}.MatrixStandardDeviations.dA =[];
    MdlMetrics{i}.MatrixStandardDeviations.dB =[];
    MdlMetrics{i}.MatrixStandardDeviations.dC =[];
    MdlMetrics{i}.MatrixStandardDeviations.dD =[];
else
    cprintf('Blue','Standard Deviation of A Matrix...\n');
    id_model{i}.dA
    MdlMetrics{i}.MatrixStandardDeviations.dA = id_model{i}.dA;
    cprintf('Black',         '          -----------------------------          \n');
    cprintf('Blue','Standard Deviation of B Matrix...\n');
    id_model{i}.dB
    MdlMetrics{i}.MatrixStandardDeviations.dB = id_model{i}.dB;
    cprintf('Black',         '          -----------------------------          \n');
    cprintf('Blue','Standard Deviation of C Matrix...\n');
    id_model{i}.dC
    MdlMetrics{i}.MatrixStandardDeviations.dC = id_model{i}.dC;
    cprintf('Black',         '          -----------------------------          \n');
    cprintf('Blue','Standard Deviation of D Matrix...\n');
    id_model{i}.dD
    MdlMetrics{i}.MatrixStandardDeviations.dD = id_model{i}.dD;
end
end

cprintf('SystemCommands','Press any key to see residual analysis... \n');
pause;
cprintf('SystemCommands','-------------------------------------------------\n');
cprintf('Blue',          'Residual analysis...\n');
resid(id_model{i},vdata,'fr');

cprintf('Green','END OF ANALYSIS. Hope you have a nice model! \n');

adv_flag = input('Do you also want to see the results of MATLAB "advice(model)" command [0/1]?');
if(adv_flag==1)
    advice(id_model{i})
end
cprintf('-SystemCommands','Press any key to see the analysis for the next model (if any)\n');
close all
end
end