function SISO_SS_3PZ = ACX_SIM_PZ_SISO_SS_3PZ(data,par_init,init_state,options,nm)
%
%   Syntax:
%   SISO_SS_3PZ = ACX_SIM_PZ_SISO_SS_3PZ(data,par_init,init_state,options)
%
%   Inputs:
%   data            : iddata object
%   par_init        : par_init(1), par_init(2),(3),(4) (5) (6) 
%   init_state      : initial state for y
%   options         : structure that contains the following
%   options.Ts         = sampling time
%           options.Disturbance == 1 means that disturbance model estimated
%           
%   Outputs:
%   T SISO_SS_3PZ  : 3 poles, 1 zero State-Space representation
%   
%   Estimates SISO State Space model based on 3 poles ,1 zero
%
%   Authors:    Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%
n = nm(1); m = nm(2);
if((n==3)&&(m==1))
    miso_struct = idgrey('SIM_PZ_SISO_SS_3PZ',[par_init  init_state], 'c', 0*options.Ts);
    SISO_SS_3PZ = pem(data,miso_struct,'Ts',0,'DisturbanceModel','None','InitialState','Zero');
    cprintf('Blue','3PZ State Space Model Identified\n');
    cprintf('Blue','Note: In case you know some parameters already you can hardcode them and make the estimation status "fixed". Type "help idproc" to find out how.\n');
end

if((n==3)&&(m==2))
    miso_struct = idgrey('SIM_PZ_SISO_SS_3P2Z',[par_init  init_state], 'c', 0*options.Ts);
    SISO_SS_3PZ = pem(data,miso_struct,'Ts',0,'DisturbanceModel','None','InitialState','Zero');
    cprintf('Blue','3PZ State Space Model Identified\n');
    cprintf('Blue','Note: In case you know some parameters already you can hardcode them and make the estimation status "fixed". Type "help idproc" to find out how.\n');
end

if((n==4)&&(m==1))
    miso_struct = idgrey('SIM_PZ_SISO_SS_4PZ',[par_init  init_state], 'c', 0*options.Ts);
    SISO_SS_3PZ = pem(data,miso_struct,'Ts',0,'DisturbanceModel','None','InitialState','Zero');
    cprintf('Blue','3PZ State Space Model Identified\n');
    cprintf('Blue','Note: In case you know some parameters already you can hardcode them and make the estimation status "fixed". Type "help idproc" to find out how.\n');
end

if((n==4)&&(m==2))
    miso_struct = idgrey('SIM_PZ_SISO_SS_4P2Z',[par_init  init_state], 'c', 0*options.Ts);
    SISO_SS_3PZ = pem(data,miso_struct,'Ts',0,'DisturbanceModel','None','InitialState','Zero');
    cprintf('Blue','3PZ State Space Model Identified\n');
    cprintf('Blue','Note: In case you know some parameters already you can hardcode them and make the estimation status "fixed". Type "help idproc" to find out how.\n');
end

end
