function TWO_I_ONE_O_3ORD_SS = ACX_SIM_TWO_I_ONE_O_3ORDER_SS(data,par_init,init_state,options)
%
%   Syntax:
%   TWO_I_ONE_O_SS = ACX_SIM_TWO_I_ONE_O_3ORDER_SS(data,par_init,init_state,options)
%   
%   Based on MATHWORKS SYS ID TOOLBOX
%
%   ### AIROBOTS COAX Small System Identification Toolbox
%
%   Inputs:
%   data            : iddata object
%   par_init        : par_init(1), par_init(2),(3),(4) init parameters of
%  \ddot{y}=par_init(1)*\dot{y}+par_init(2)*y +par_init(3)*u +par_init(4)*u
%   init_state      : initial state for y (not two states! its MISO ID) 
%   options         : structure that contains the following
%   options.Ts         = sampling time
%           options.Disturbance == 1 means that disturbance model estimated
%           
%   Outputs:
%   TWO_I_ONE_O_SS  : 2nd order SISO State Space Model
%   
%   Estimates 2 Input - 1 Output MISO Model
%
%   Authors:    Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

miso_struct = idgrey('SIM_TwoInp_OneOut_3rdOrder_SS',[par_init  init_state], 'c', 0*options.Ts);
StabTest = ACX_SIM_Check_SS_Stability(miso_struct);
TWO_I_ONE_O_3ORD_SS = pem(data,miso_struct,'Ts',0,'DisturbanceModel','None','InitialState','Zero');

cprintf('Blue','TWO Inputs - ONE Output 3rd ORDER MISO State Space Model Identified\n');
cprintf('Blue','Note: In case you know some parameters already you can hardcode them and make the estimation status "fixed". Type "help idproc" to find out how.\n');

end
