function [mag,phase] = SIM_Chirp_Z_FreqPlotSampledData(y,u,Ts,f1,f2,m,options)
%
%
%   Frequency Plot based on the Chirp-Z Transform of Sampled Data
%   
%   Inputs  :
%   y       : the measured output
%   u       : the measured input
%   Ts      : the sample period
%   f1,f2   : the Chirp-Z Zoom Frequencies
%   m       : a scalar that specifies the length of the transform
%   options : structure with the following options
%   options.dB      : if == 1 outputs the magnitude in dB
%   options.plot   : if == 1 plots the magnitude - phase with linear
%   x-axis
%
%   Outputs :
%   mag     : magnitude of Output/Input Ratio (in dB if options.dB == 1)
%   phase   : phase of Output/Input Ratio
%
%   Authors : Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

%%  Check data
FlagError = 0;
if((isempty(y))||(isempty(u)))
    disp('No Data: nothing has been done');
    FlagError = 1;
end
    
if(length(y)~=length(u))
    disp('different size of input-output data: nothing has been done');
    FlagError =1;
end

if(FlagError~=1)
%% Compute the Chirp-Z Transforms of the Signal
Fs = 1/Ts;
w = exp(-1i*2*pi*(f2-f1)/(m*Fs));
a = exp(1i*2*pi*f1/Fs);

Y_czt = czt(y,m,w,a);
U_czt = czt(u,m,w,a);

YUratio(1:length(Y_czt))=0;
for i =1:length(Y_czt)
YUratio(i) = Y_czt(i)/U_czt(i);
end

if(options.dB == 0)
    mag = YUratio;
else
    mag = 20*log10(abs(YUratio));
end

phase = angle(YUratio);

if(options.plot==1)
    wwlin = linspace(f1,f2,length(mag));
    figure;
    subplot(2,1,1)
    plot(wwlin,mag);
    subplot(2,1,2)
    plot(wwlin,phase/pi*180);
end

end
end