function [PSDuu,PSDyy,PSDuy] = SIM_PSD_MISO(u,y,options)
%   
%   MISO Power Spectral Density Estimate: auto PSD input, output, cross PSD
%   
%   Syntax:
%   [PSDuu,PSDyy,PSDuy] = SIM_PSD_MISO(u,y,options)
%
%   Inputs:
%   u           : Inputs matrix
%   y           : Output vector
%   options     : structure that contains the options on how to do the
%   spectrogram and how to export data. Specifically: 
%           options.Fs      : sampling frequency
%           options.Window  : Windowing function
%           options.noverlap: no overlap value
%           options.nfft    : nfft value
%           options.plot    : if == 1 plots the Random-Error function
%
%   Outputs:
%   PSDuu       : Input auto PSD for all in
%   PSDyy       : Output auto PSD
%   PSDuy       : Input/Output cross PSD for all inputs
%
%   Authors:    Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%
[~,M_i] = size(u);

for i = 1:M_i
    [PSDuu(:,i),PSDyy,PSDuy(:,i)] = SIM_PSD_IO(u(:,i),y,options);
    cprintf('SystemCommands','Press any button to see next Input-Output PSD estimate (if any)\n');
    pause;
    close all
end
    