%%  Quick Plotting Functionality for ACX Linear Simulator
%   This script illustrates the most important responses and input/output
%   relations of the ACX Linear Simulator assuming that all subsystems are
%   executed in closed-loop mode. 
%
%   Authors: Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)


%%  Create Options Object
clear h;
Slowest_Oscillation = 5;
F1 = 0.1;
F2 = 2;
BW = 10;
TC = 0.5;
OV = 10;
ZETAD = 0.35;
STC = 1;
FITP = 30;
SISOoptionsFAST = SIM_CreateSISOoptions(Slowest_Oscillation,F1,F2,Ts,BW,TC,OV,ZETAD,STC,FITP)

Slowest_Oscillation = 8;
F1 = 0.05;
F2 = 1;
BW = 6;
TC = 0.8;
OV = 10;
ZETAD = 0.45;
STC = 1.5;
FITP = 20;
SISOoptionsMED = SIM_CreateSISOoptions(Slowest_Oscillation,F1,F2,Ts,BW,TC,OV,ZETAD,STC,FITP)


Slowest_Oscillation = 15;
F1 = 0.001;
F2 = 0.5;
BW = 3;
TC = 1.5;
OV = 10;
ZETAD = 0.45;
STC = 2.5;
FITP = 10;
SISOoptionsSLOW = SIM_CreateSISOoptions(Slowest_Oscillation,F1,F2,Ts,BW,TC,OV,ZETAD,STC,FITP)


cnt = 1;
%%  Plot Attitude
h(cnt) = figure('Name','Attitude Responses')
ACX_SIM_Plot_Attitude(ATTI_SIM,Ts)
cnt = cnt + 1;

%%  Plot Yaw
h(cnt) = figure('Name','Yaw Responses');
ACX_SIM_Plot_Yaw(YAWR,Ts)
cnt = cnt + 1;

%%  Plot Heave

h(cnt) = figure('Name','Heave Responses');
ACX_SIM_Plot_Heave(HEAVEZW,Ts)
cnt = cnt + 1;

%%  Plot Position

h(cnt) = figure('Name','Position Responses');
if(ctrl_pos_select(end) == 2)
    ACX_SIM_Plot_Trajectory(XY_VEL_RM,X_WPTS_COARSE,Y_WPTS_COARSE,X_WPTS,Y_WPTS)
else
    ACX_SIM_PlotXY(XY_VEL_RM,Ts)
end
cnt = cnt + 1;

%%  p-rate U_roll - P check

h(cnt) = figure('Name','u_roll-> p check');

input_vec = SIM_Datasets.ControlActions.Normalized.u_roll;
output_vec = SIM_Datasets.Attitude.p_resp;

data = iddata(output_vec,input_vec,Ts);

if(exist('time_vec','var')==0)
    time_vec = Ts*(1:length(input_vec)) - Ts;
end

IOCheck = ACX_SIM_SISO_ResponseCheck(input_vec,output_vec,SISOoptionsFAST)

cnt = cnt + 1;

h(cnt) = figure('Name','u_roll->p frequency analysis');
FRD_Analysis = ACX_SIM_SISO_FRD_Analysis(input_vec,output_vec,Ts,SISOoptionsFAST)
cnt = cnt + 1;

h(cnt) = figure('Name','u_roll->p spectrogram');
[Spectro] = SIM_SpectrogramIO(input_vec,output_vec,SISOoptionsFAST);
cnt = cnt + 1;

%%  p-rate U_pitch - q check

h(cnt) = figure('Name','u_pitch-> q check');

input_vec = SIM_Datasets.ControlActions.Normalized.u_pitch;
output_vec = SIM_Datasets.Attitude.q_resp;

data = iddata(output_vec,input_vec,Ts);

if(exist('time_vec','var')==0)
    time_vec = Ts*(1:length(input_vec)) - Ts;
end

IOCheck = ACX_SIM_SISO_ResponseCheck(input_vec,output_vec,SISOoptionsFAST)

cnt = cnt + 1;

h(cnt) = figure('Name','u_pitch->q frequency analysis');
FRD_Analysis = ACX_SIM_SISO_FRD_Analysis(input_vec,output_vec,Ts,SISOoptionsFAST);
cnt = cnt + 1;

h(cnt) = figure('Name','u_pitch->q spectrogram');
[Spectro] = SIM_SpectrogramIO(input_vec,output_vec,SISOoptionsFAST);
cnt = cnt + 1;
    
%%  u_yaw -> r

h(cnt) = figure('Name','u_yaw-> r check');

input_vec = SIM_Datasets.ControlActions.Normalized.u_yaw;
output_vec = SIM_Datasets.YawHeave.r_resp;

data = iddata(output_vec,input_vec,Ts);

if(exist('time_vec','var')==0)
    time_vec = Ts*(1:length(input_vec)) - Ts;
end

IOCheck = ACX_SIM_SISO_ResponseCheck(input_vec,output_vec,SISOoptionsMED)

cnt = cnt + 1;

h(cnt) = figure('Name','u_yaw->r frequency analysis');
FRD_Analysis = ACX_SIM_SISO_FRD_Analysis(input_vec,output_vec,Ts,SISOoptionsMED);
cnt = cnt + 1;

h(cnt) = figure('Name','u_yaw->r spectrogram');
[Spectro] = SIM_SpectrogramIO(input_vec,output_vec,SISOoptionsMED);
cnt = cnt + 1;


%%  u_thrust -> w

h(cnt) = figure('Name','u_thrust-> w check');

input_vec = SIM_Datasets.ControlActions.Normalized.u_thrust;
output_vec = SIM_Datasets.YawHeave.w_resp;

data = iddata(output_vec,input_vec,Ts);

if(exist('time_vec','var')==0)
    time_vec = Ts*(1:length(input_vec)) - Ts;
end

IOCheck = ACX_SIM_SISO_ResponseCheck(input_vec,output_vec,SISOoptionsSLOW)

cnt = cnt + 1;

h(cnt) = figure('Name','u_thrust->w frequency analysis');
FRD_Analysis = ACX_SIM_SISO_FRD_Analysis(input_vec,output_vec,Ts,SISOoptionsSLOW);
cnt = cnt + 1;

h(cnt) = figure('Name','u_thrust->w spectrogram');
[Spectro] = SIM_SpectrogramIO(input_vec,output_vec,SISOoptionsSLOW);
cnt = cnt + 1;

%%  theta_resp -> u

h(cnt) = figure('Name','theta_resp-> u check');

input_vec = SIM_Datasets.Attitude.theta_resp;
output_vec = SIM_Datasets.Position.u_resp;

data = iddata(output_vec,input_vec,Ts);

if(exist('time_vec','var')==0)
    time_vec = Ts*(1:length(input_vec)) - Ts;
end

IOCheck = ACX_SIM_SISO_ResponseCheck(input_vec,output_vec,SISOoptionsSLOW)

cnt = cnt + 1;

h(cnt) = figure('Name','theta_resp->u frequency analysis');
FRD_Analysis = ACX_SIM_SISO_FRD_Analysis(input_vec,output_vec,Ts,SISOoptionsSLOW);
cnt = cnt + 1;

h(cnt) = figure('Name','theta_resp->u spectrogram');
[Spectro] = SIM_SpectrogramIO(input_vec,output_vec,SISOoptionsSLOW);
cnt = cnt + 1;

%%  phi_resp -> v

h(cnt) = figure('Name','phi_resp-> v check');

input_vec = SIM_Datasets.Attitude.phi_resp;
output_vec = SIM_Datasets.Position.v_resp;

data = iddata(output_vec,input_vec,Ts);

if(exist('time_vec','var')==0)
    time_vec = Ts*(1:length(input_vec)) - Ts;
end

IOCheck = ACX_SIM_SISO_ResponseCheck(input_vec,output_vec,SISOoptionsSLOW)

cnt = cnt + 1;

h(cnt) = figure('Name','phi_resp->v frequency analysis');
FRD_Analysis = ACX_SIM_SISO_FRD_Analysis(input_vec,output_vec,Ts,SISOoptionsSLOW);
cnt = cnt + 1;

h(cnt) = figure('Name','phi_resp->v spectrogram');
[Spectro] = SIM_SpectrogramIO(input_vec,output_vec,SISOoptionsSLOW);
cnt = cnt + 1;

%%

ACX_SIM_SetupPlots(h)
%linkaxes(h,'off');
%clc;

